
# This file was generated by 'versioneer.py' (0.19) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2022-03-07T12:27:54-0700",
 "dirty": false,
 "error": null,
 "full-revisionid": "7d4349e332fcba2bc3f266267421531b3ec5d3e6",
 "version": "1.22.3"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
